/*
    Mohawk Software Framework by Mohawk Software
    Copyright (C) 1998-2001 Mark L. Woodward
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
    MA 02111-1307, USA
 
    If you want support or to commercially license this library, the author
    can be reached at info@mohawksoft.com
*/ 
#ifndef _MFSERIAL_
#define _MFSERIAL_

#ifdef X86SERIAL
#include <termios.h>
#define FILE_DESC int
#define INVALID_FILE (-1)

enum MFSPBaud
{
	MFSPBaud_300=B300,
	MFSPBaud_1200=B1200,
	MFSPBaud_2400=B2400,
	MFSPBaud_4800=B4800,
	MFSPBaud_9600=B9600,
	MFSPBaud_19200=B19200,
	MFSPBaud_38400=B38400,
	MFSPBaud_57600=B57600,
	MFSPBaud_115200=B115200
};
 
// #define COMM_PARAMS struct termios
typedef struct termios COMM_PARAMS;

#endif

#ifdef WIN32
#define FILE_DESC HANDLE
#define INVALID_FILE INVALID_HANDLE_VALUE
enum MFSPBaud
{
	MFSPBaud_300=CBR_300,
	MFSPBaud_1200=CBR_1200,
	MFSPBaud_2400=CBR_2400,
	MFSPBaud_4800=CBR_4800,
	MFSPBaud_9600=CBR_9600,
	MFSPBaud_19200=CBR_19200,
	MFSPBaud_38400=CBR_38400,
	MFSPBaud_57600=CBR_57600,
	MFSPBaud_115200=CBR_115200
};

typedef DCB	COMM_PARAMS;
#endif

enum MFSPParity
{
	
	MFSPParity_ODD,
	MFSPParity_EVEN,
	MFSPParity_MARK,
	MFSPParity_SPACE
};

enum MFSPStopBits
{
  	MFSPStopBits_1,	// 1
  	MFSPStopBits_2 	// 2
};

#define MFSP_FLAGS_XON 0x01

/** a class to open and program a serial I/O port */
class MFSerialPort :  public MIoFile
{
	protected:
	COMM_PARAMS	m_comprmPrev;
	COMM_PARAMS	m_comprmNew;
	
	public:
	MFSerialPort(void);
	virtual	~MFSerialPort(void);
	/** Sets serial port parameters */
	virtual Boolean SetSerialParams(MFSPBaud baud, int bytesize, MFSPParity parity, MFSPStopBits stop, unsigned flags);
#ifdef X86SERIAL
	termios	m_savetty;
	int	m_word;

	void sethwf(int on);
	void setrts();
	void dtrtoggle(int sec) ;
	void sendbreak();
	int getdcd();
	void savestate();
	void restorestate();
	void nohang();
	void hupcl(int on);
	void flush();
	int readchk();
	int getmaxspd();
	void setparms(char *baudr, char *par, char *bits, int hwf, int swf);
	void setparms(int baud, int par, int bits, int hwf, int swf);
	int comwait(int *stt);
#endif	
};



#endif 
